A Python client library for Cisco NSO (previously tail-f)

## Installation

To install use pip:

    $ pip install pynso-restconf

Or clone the repo:

    $ git clone https://github.com/workfloworchestrator/pynso-restconf.git
    $ python setup.py install

## Usage

    from pprint import pprint

    from pynso import NSOClient

    # Setup a client
    client = NSOClient('10.123.92.12', 'admin', 'admin')

    # Get information about the API
    print('Getting API version number')
    pprint(client.info())

    # Get the information about the running datastore
    print('Getting information about the running datastore')
    pprint(client.get_datastore("running"))